package com.aucma.dms.service;

import com.aucma.dms.domain.DmsBaseLubeStation;

import java.util.List;

/**
 * 润滑部位信息Service接口
 * 
 * @author Open Platform
 * @date 2024-01-12
 */
public interface IDmsBaseLubeStationService 
{
    /**
     * 查询润滑部位信息
     * 
     * @param lubeStationId 润滑部位信息主键
     * @return 润滑部位信息
     */
    public DmsBaseLubeStation selectDmsBaseLubeStationByLubeStationId(Long lubeStationId);

    /**
     * 查询润滑部位信息列表
     * 
     * @param dmsBaseLubeStation 润滑部位信息
     * @return 润滑部位信息集合
     */
    public List<DmsBaseLubeStation> selectDmsBaseLubeStationList(DmsBaseLubeStation dmsBaseLubeStation);

    /**
     * 新增润滑部位信息
     * 
     * @param dmsBaseLubeStation 润滑部位信息
     * @return 结果
     */
    public int insertDmsBaseLubeStation(DmsBaseLubeStation dmsBaseLubeStation);

    /**
     * 修改润滑部位信息
     * 
     * @param dmsBaseLubeStation 润滑部位信息
     * @return 结果
     */
    public int updateDmsBaseLubeStation(DmsBaseLubeStation dmsBaseLubeStation);

    /**
     * 批量删除润滑部位信息
     * 
     * @param lubeStationIds 需要删除的润滑部位信息主键集合
     * @return 结果
     */
    public int deleteDmsBaseLubeStationByLubeStationIds(Long[] lubeStationIds);

    /**
     * 删除润滑部位信息信息
     * 
     * @param lubeStationId 润滑部位信息主键
     * @return 结果
     */
    public int deleteDmsBaseLubeStationByLubeStationId(Long lubeStationId);
}
