package com.aucma.dms.controller;

import com.aucma.common.core.controller.BaseController;
import com.aucma.common.core.domain.AjaxResult;
import com.aucma.common.core.page.TableDataInfo;
import com.aucma.common.utils.poi.ExcelUtil;
import com.aucma.dms.domain.DmsBaseLubeStation;
import com.aucma.dms.service.IDmsBaseLubeStationService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import java.util.List;




/**
 * 润滑部位信息Controller
 *
 * @author Open Platform
 * @date 2024-01-12
 */
@RestController
@RequestMapping("/dms/lubeStation")
public class DmsBaseLubeStationController extends BaseController
{
    @Autowired
    private IDmsBaseLubeStationService dmsBaseLubeStationService;

    /**
     * 查询润滑部位信息列表
     */
    //@PreAuthorize("@ss.hasPermi('dms:lubeStation:list')" )
    @GetMapping("/list")
    public TableDataInfo list(DmsBaseLubeStation dmsBaseLubeStation)
    {
        startPage();
        List<DmsBaseLubeStation> list = dmsBaseLubeStationService.selectDmsBaseLubeStationList(dmsBaseLubeStation);
        return getDataTable(list);
    }

    /**
     * 导出润滑部位信息列表
     */
    //@PreAuthorize("@ss.hasPermi('dms:lubeStation:export')" )
    ////@Log(title = "润滑部位信息", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, DmsBaseLubeStation dmsBaseLubeStation)
    {
        List<DmsBaseLubeStation> list = dmsBaseLubeStationService.selectDmsBaseLubeStationList(dmsBaseLubeStation);
        ExcelUtil<DmsBaseLubeStation> util = new ExcelUtil<DmsBaseLubeStation>(DmsBaseLubeStation.class);
        util.exportExcel(response, list, "润滑部位信息数据");
    }

    /**
     * 获取润滑部位信息详细信息
     */
    //@PreAuthorize("@ss.hasPermi('dms:lubeStation:query')" )
    @GetMapping(value = "/{lubeStationId}")
    public AjaxResult getInfo(@PathVariable("lubeStationId") Long lubeStationId)
    {
        return success(dmsBaseLubeStationService.selectDmsBaseLubeStationByLubeStationId(lubeStationId));
    }

    /**
     * 新增润滑部位信息
     */
    //@PreAuthorize("@ss.hasPermi('dms:lubeStation:add')" )
    ////@Log(title = "润滑部位信息", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody DmsBaseLubeStation dmsBaseLubeStation)
    {
        return toAjax(dmsBaseLubeStationService.insertDmsBaseLubeStation(dmsBaseLubeStation));
    }

    /**
     * 修改润滑部位信息
     */
    //@PreAuthorize("@ss.hasPermi('dms:lubeStation:edit')" )
    ////@Log(title = "润滑部位信息", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody DmsBaseLubeStation dmsBaseLubeStation)
    {
        return toAjax(dmsBaseLubeStationService.updateDmsBaseLubeStation(dmsBaseLubeStation));
    }

    /**
     * 删除润滑部位信息
     */
    //@PreAuthorize("@ss.hasPermi('dms:lubeStation:remove')" )
    ////@Log(title = "润滑部位信息", businessType = BusinessType.DELETE)
	@DeleteMapping("/{lubeStationIds}")
    public AjaxResult remove(@PathVariable Long[] lubeStationIds)
    {
        return toAjax(dmsBaseLubeStationService.deleteDmsBaseLubeStationByLubeStationIds(lubeStationIds));
    }
}
